@@ -7,8 +7,8 @@
 #include <fxkeys.h>
 
 #include "icons.h"
+#include "xfeutils.h"
 #include "FileDialog.h"
-#include "File.h"
 #include "ArchInputDialog.h"
 
 
@@ -17,8 +17,8 @@ FXDEFMAP(ArchInputDialog) ArchInputDialogMap[]=
 {
 	FXMAPFUNC(SEL_KEYPRESS,0,ArchInputDialog::onCmdKeyPress),
 	FXMAPFUNC(SEL_COMMAND,ArchInputDialog::ID_BROWSE_PATH,ArchInputDialog::onCmdBrowsePath),
-	FXMAPFUNCS(SEL_COMMAND,ArchInputDialog::ID_FORMAT_TAR_GZ,ArchInputDialog::ID_FORMAT_LZH,ArchInputDialog::onCmdOption),
-	FXMAPFUNCS(SEL_UPDATE,ArchInputDialog::ID_FORMAT_TAR_GZ,ArchInputDialog::ID_FORMAT_LZH,ArchInputDialog::onUpdOption),
+	FXMAPFUNCS(SEL_COMMAND,ArchInputDialog::ID_FORMAT_TAR_GZ,ArchInputDialog::ID_FORMAT_ARJ,ArchInputDialog::onCmdOption),
+	FXMAPFUNCS(SEL_UPDATE,ArchInputDialog::ID_FORMAT_TAR_GZ,ArchInputDialog::ID_FORMAT_ARJ,ArchInputDialog::onUpdOption),
 };
 
 
@@ -72,6 +72,7 @@ ArchInputDialog::ArchInputDialog(FXWindow *win,FXString inp):
 	option_z = new FXOption(popup,_("Z\tArchive format is Z"),NULL,this,ID_FORMAT_Z,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_rar = new FXOption(popup,_("rar\tArchive format is rar"),NULL,this,ID_FORMAT_RAR,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_lzh = new FXOption(popup,_("lzh\tArchive format is lzh"),NULL,this,ID_FORMAT_LZH,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
+	option_arj = new FXOption(popup,_("arj\tArchive format is arj"),NULL,this,ID_FORMAT_ARJ,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	optionmenu = new FXOptionMenu(matrix4,popup,LAYOUT_TOP|FRAME_RAISED|FRAME_THICK|JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 }
 
@@ -167,7 +168,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.gz";
 			input->setText(str);
 		}
-		else if (ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar.gz";
@@ -213,7 +214,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.bz2";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar.bz2";
@@ -269,7 +270,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar";
@@ -319,7 +320,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.Z";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar.Z";
@@ -375,7 +376,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".gz";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".gz";
@@ -426,7 +427,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".bz2";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".bz2";
@@ -482,7 +483,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".Z";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".Z";
@@ -532,7 +533,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".zip";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".zip";
@@ -588,7 +589,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".7z";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".7z";
@@ -644,7 +645,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".rar";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="lzh" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".rar";
@@ -700,7 +701,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".lzh";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="arj")
 		{
 			str=str.left(str.length()-4);
 			str=str+".lzh";
@@ -724,6 +725,61 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			input->setText(str);
 		}
 	}
+	else if (FXSELID(sel)==ID_FORMAT_ARJ)
+	{
+		// Handle different archive formats
+		if (ext1=="arj")
+		{
+			input->setText(str);
+		}
+		else if (ext2=="tar.bz2")
+		{
+			str=str.left(str.length()-8);
+			str=str+".arj";
+			input->setText(str);
+		}
+		else if (ext2=="tar.gz")
+		{
+			str=str.left(str.length()-7);
+			str=str+".arj";
+			input->setText(str);
+		}
+		else if (ext2=="tar.z")
+		{
+			str=str.left(str.length()-6);
+			str=str+".arj";
+			input->setText(str);
+		}
+		else if (ext1=="tbz2")
+		{
+			str=str.left(str.length()-5);
+			str=str+".arj";
+			input->setText(str);
+		}
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
+		{
+			str=str.left(str.length()-4);
+			str=str+".arj";
+			input->setText(str);
+		}
+		else if (ext1=="gz")
+		{
+			str=str.left(str.length()-3);
+			str=str+".arj";
+			input->setText(str);
+		}
+		else if (ext1=="z")
+		{
+			str=str.left(str.length()-2);
+			str=str+".arj";
+			input->setText(str);
+		}
+		else
+		{			
+			str=str+".arj";
+			input->setText(str);
+		}
+	}
 			
 	return 1;
 }
@@ -784,6 +840,10 @@ long ArchInputDialog::onUpdOption(FXObject*,FXSelector sel,void*)
 	{
 		optionmenu->setCurrent(option_lzh);	
 	}
+	else if (ext1=="arj")
+	{
+		optionmenu->setCurrent(option_arj);	
+	}
 	else
 	{			
 		optionmenu->setCurrent(option_tgz);	
