@@ -16,6 +16,8 @@
 // Used to limit the dialog size when long file names are used
 #define MAX_MESSAGE_LENGTH 128
 
+extern FXString homedir;
+
 
 FXDEFMAP(BrowseInputDialog) BrowseInputDialogMap[]=
 {
@@ -72,10 +74,7 @@ BrowseInputDialog::BrowseInputDialog(FXWindow *win,FXString inp,FXString message
 		new FXLabel(contents,_("=> Warning: file name is not UTF-8 encoded!"),NULL,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW);
 	
 	// Initial directory for browsing
-	FXString homelocation=getenv("HOME");
-    if(homelocation=="")
-        homelocation=ROOTDIR;
-	initialdir=homelocation;
+	initialdir=homedir;
 }
 
 
