@@ -19,9 +19,9 @@
 
 #include <fx.h>
 
-#include "CommandWindow.h"
-#include "MessageBox.h"
 #include "icons.h"
+#include "MessageBox.h"
+#include "CommandWindow.h"
 
 
 // Map
@@ -148,7 +148,7 @@ FXint CommandWindow::execCmd(FXString command)
 	// Create child process
     pid = fork();
     if (pid == -1)
-        return -1;  // fork() did not work.
+        return -1;  // fork() failed
     
 	if (pid == 0)
     {
