@@ -13,6 +13,7 @@ protected:
     {}
 public:
     long onKeyPress(FXObject*,FXSelector,void*);
+    long onKeyRelease(FXObject*,FXSelector,void*);
     long onClose(FXObject*,FXSelector,void*);
     long onCmdAccept(FXObject*,FXSelector,void*);
     long onCmdCancel(FXObject*,FXSelector,void*);
@@ -26,6 +27,7 @@ public:
     };
 public:
     DialogBox(FXWindow* win,const FXString& name,FXuint opts=DECOR_TITLE|DECOR_BORDER,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=10,FXint pr=10,FXint pt=10,FXint pb=10,FXint hs=4,FXint vs=4);
+    DialogBox(FXApp* a,const FXString& name,FXuint opts=DECOR_TITLE|DECOR_BORDER,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=10,FXint pr=10,FXint pt=10,FXint pb=10,FXint hs=4,FXint vs=4);
     virtual void show(FXuint placement=PLACEMENT_CURSOR);
     virtual void create();
     FXuint execute(FXuint placement=PLACEMENT_CURSOR);
