@@ -1069,8 +1069,24 @@ FXbool DirList::collapseTree(TreeItem* tree,FXbool notify)
         {
             // As a memory saving feature, all knowledge below this item
             // is deleted; we'll just recreate it when its reexpanded!
-            //removeItems(item->first,item->last);
-            //recalc();
+ 
+ 
+ 
+           
+           
+           // Faut-il garder ceci??????
+           removeItems(tree->first,tree->last);
+           recalc();
+		   // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+
+
+
+
+
+
+
+
+
         }
         return TRUE;
     }
@@ -1625,10 +1641,8 @@ fnd:
                 item->openIcon=minilinkicon;
             }
 
-			// Data passed to the item->data pointer and used to update the tooltip
-			FXString strdata=item->label+"\t"+type+"\t"+mod+"\t"+usrid+"\t"+grpid+"\t"+atts+"\t"+del+"\t"+pathname;
-			FXMALLOC(&item->data,FXchar,strdata.length()+1);
-			memcpy(item->data,strdata.text(),strdata.length()+1);	
+			// Data used to update the tooltip
+			item->tdata=item->label+"\t"+type+"\t"+mod+"\t"+usrid+"\t"+grpid+"\t"+atts+"\t"+del+"\t"+pathname;
 
             // Create item
             if(id())
@@ -1643,7 +1657,6 @@ fnd:
     for(item=oldlist; item; item=link)
     {
         link=item->link;
-		FXFREE(&item->data);
         removeItem(item,TRUE);
     }
 
