@@ -30,6 +30,7 @@ protected:
     DirItem    *list;               // List of child items
     FXlong      size;               // File size (if a file)
     FXTime      date;               // Time of item
+    FXString	tdata;				// Tooltip data
 protected:
     DirItem():assoc(NULL),link(NULL),list(NULL),size(0L),date(0)
     {}
@@ -89,6 +90,10 @@ public:
     {
         return date;
     }
+    FXString getTooltipData() const
+    {
+		return tdata;
+	}
 };
 
 
