@@ -46,8 +46,8 @@ extern FXbool allowPopupScroll;
 extern FXStringDict* fsdevices;
 extern FXStringDict* mtdevices;
 #endif
-
 extern FXuint single_click;
+extern FXString xdgdatahome;
 
 
 
@@ -388,12 +388,9 @@ DirPanel::DirPanel(FXWindow *owner, FXComposite *p, FXColor listbackcolor, FXCol
     status->setSelector(FXSEL(SEL_UPDATE,DirPanel::ID_TITLE));
 
 	// Home and trahscan locations
-	homelocation=getenv("HOME");
-    if(homelocation=="")
-        homelocation=ROOTDIR;
-	trashlocation=homelocation+PATHSEPSTRING+TRASHPATH;
-	trashfileslocation=homelocation+PATHSEPSTRING+TRASHFILESPATH;
-	trashinfolocation=homelocation+PATHSEPSTRING+TRASHINFOPATH;
+	trashlocation=xdgdatahome+PATHSEPSTRING TRASHPATH;
+	trashfileslocation=xdgdatahome + PATHSEPSTRING TRASHFILESPATH;
+	trashinfolocation=xdgdatahome + PATHSEPSTRING TRASHINFOPATH;
 	
 	// Start location (we return to the start location after each chdir)
 	startlocation=FXSystem::getCurrentDirectory();
@@ -655,7 +652,7 @@ long DirPanel::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 
 #if defined(linux)
 		if (::isLink(dir))
-			dir=readlink(dir);
+			dir=::readLink(dir);
 		if(fsdevices->find(dir.text()) || mtdevices->find(dir.text()))
 		{
 			new FXMenuCommand(menu,_("M&ount"),maphosticon,this,ID_MOUNT);
@@ -987,8 +984,14 @@ long DirPanel::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr)
 				while (1)
 				{
 					end=clipboard.find('\n',end);
-					if (end<0)
+					if (end<0) // Last line
+					{
+						end=clipboard.length();
+						url=clipboard.mid(beg,end-beg+1);
+						filepath=FXURL::decode(FXURL::fileFromURL(url));
+						str += filepath;
 						break;
+					}
 					url=clipboard.mid(beg,end-beg+1);
 					filepath=FXURL::decode(FXURL::fileFromURL(url));
 					str += filepath;
@@ -1011,8 +1014,14 @@ long DirPanel::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr)
 				while (1)
 				{
 					end=clipboard.find('\n',end);
-					if (end<0)
+					if (end<0) // Last line
+					{
+						end=clipboard.length();
+						url=clipboard.mid(beg,end-beg+1);
+						filepath=FXURL::decode(FXURL::fileFromURL(url));
+						str += filepath;
 						break;
+					}
 					url=clipboard.mid(beg,end-beg+1);
 					filepath=FXURL::decode(FXURL::fileFromURL(url));
 					str += filepath;
@@ -1020,7 +1029,7 @@ long DirPanel::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr)
 					beg=end;
 				}
 				end=str.length();
-				str=str.mid(0,end-1);
+				//str=str.mid(0,end-1);
 			}
 			
 			if(!str.empty())
@@ -1052,8 +1061,7 @@ long DirPanel::onCmdCopyCut(FXObject*,FXSelector sel,void*)
 	// Current item
     DirItem* item=(DirItem*)list->getCurrentItem();
 	FXString pathname=list->getItemPathname((TreeItem*)item);
-
-	clipboard=FXURL::encode(::fileToURI(pathname))+"\n";
+	clipboard=FXURL::encode(::fileToURI(pathname));
 		
 	// Acquire the clipboard
 	FXDragType types[4];
@@ -1464,7 +1472,7 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
 
 	// One source
 	File *f=NULL;
-	FXbool ret;
+	FXint ret;
     if(num==1)
 	{
 		// An empty source file name corresponds to the ".." file
@@ -1814,13 +1822,13 @@ long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
 	// Confirm empty directory deletion
 	if (confirm_del & confirm_del_emptydir)
 	{
-		if (::isEmptyDir(pathname)==0)
+		if (::isEmptyDir(pathname)==0 && !::isLink(pathname))
 		{
 			// Dialog to confirm file deletion
 			f->hideProgressDialog();
-			FXString message;
-			message.format(_("Folder %s is not empty, delete it anyway?"),pathname.text());
-			MessageBox box(this,_("Confirm Delete"),message,delete_big_permicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
+			FXString msg;
+			msg.format(_("Folder %s is not empty, delete it anyway?"),pathname.text());
+			MessageBox box(this,_("Confirm Delete"),msg,delete_big_permicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
 			if(box.execute(PLACEMENT_CURSOR) == BOX_CLICKED_CANCEL)
 				goto end;
 			f->showProgressDialog();
@@ -1833,9 +1841,9 @@ long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
     {
 		// Dialog to confirm directory deletion
 		f->hideProgressDialog();
-		FXString str;
-		str.format(_("Folder %s is write-protected, definitively delete it anyway?"),pathname.text());
-		MessageBox box(this,_("Confirm Delete"),str,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
+		FXString msg;
+		msg.format(_("Folder %s is write-protected, definitively delete it anyway?"),pathname.text());
+		MessageBox box(this,_("Confirm Delete"),msg,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
 		FXuint answer=box.execute(PLACEMENT_SCREEN);
 		if(answer == BOX_CLICKED_OK)
 		{
@@ -1943,7 +1951,7 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 			createTrashinfo(pathname,trashpathname,trashfileslocation,trashinfolocation);
 
 			// Move file to trash files location
-			FXbool ret=f->move(pathname,trashpathname);
+			FXint ret=f->move(pathname,trashpathname);
 
 			// An error has occurred
 			if (ret==0 && !f->isCancelled())
@@ -1976,7 +1984,7 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 		createTrashinfo(pathname,trashpathname,trashfileslocation,trashinfolocation);
 
 		// Move file to trash files location
-		FXbool ret=f->move(pathname,trashpathname);
+		FXint ret=f->move(pathname,trashpathname);
 
 		// An error has occurred
 		if (ret==0 && !f->isCancelled())
@@ -2105,7 +2113,7 @@ long DirPanel::onCmdDirRestore(FXObject*,FXSelector,void*)
 		}
 
 		// Move file to original location (with restore option)
-		FXbool ret=f->move(pathname,origpathname,TRUE);
+		FXint ret=f->move(pathname,origpathname,TRUE);
 		
 		// An error has occurred
 		if (ret==0 && !f->isCancelled())
@@ -2552,6 +2560,7 @@ long DirPanel::onUpdTitle(FXObject* sender,FXSelector,void*)
 		mainWindow->setTitle("Xfe (root) - " + path);
 	else
 		mainWindow->setTitle("Xfe - " + path);
+
     return 1;
 }
 
