@@ -10,7 +10,7 @@ class IconList;
 class FileList;
 
 
-// Icon List options (prefixed by underscore to avoid conflict with the FOX library)
+// Icon List options (prefixed with an underscore to avoid conflict with the FOX library)
 enum {
   _ICONLIST_EXTENDEDSELECT = 0,                // Extended selection mode
   _ICONLIST_SINGLESELECT   = 0x00100000,       // At most one selected item
@@ -22,7 +22,8 @@ enum {
   _ICONLIST_BIG_ICONS      = 0x01000000,       // Big Icon mode
   _ICONLIST_ROWS           = 0,                // Row-wise mode
   _ICONLIST_COLUMNS        = 0x02000000,       // Column-wise mode
-  _ICONLIST_SEARCH         = 0x10000000,       // Icon list is a search list (must be the same value as in FileList)
+  _ICONLIST_SEARCH	       = 0x10000000,       // Icon list is a search list (must be the same value as in FileList)
+  _ICONLIST_STANDARD       = 0x20000000,       // Icon list is a not a file list and not a search list
   _ICONLIST_NORMAL         = _ICONLIST_EXTENDEDSELECT
   };
 
@@ -230,9 +231,11 @@ protected:
     FXbool             state;             // State of item
 	FXbool			   allowTooltip;      // Allow tooltip in single click mode
 	FXuint			   numsortheader;     // Index of the sorted column
-	FXdouble           headerpct[9];      // Header sizes, relatively to the list width (in percent)
+	FXdouble           headerpct[10];     // Header sizes, relatively to the list width (in percent)
 	FXint			   count;             // Counter used to properly initialize the relative header sizes
 	FXbool 			   autosize;
+	FXbool             ignorecase;        // Case sensitivity for file name sorting
+	FXbool			   initheaderpct;	  // Indicates we have to initialize the headerpct for the deletion columns
 protected:
     IconList()
 	{}
@@ -290,7 +293,8 @@ public:
     long onCmdGetIntValue(FXObject*,FXSelector,void*);
     long onCmdSetIntValue(FXObject*,FXSelector,void*);
 	long onCmdToggleAutosize(FXObject*,FXSelector,void*);
-	long onUpdToggleAutosize(FXObject* sender,FXSelector,void*);
+	long onUpdToggleAutosize(FXObject*,FXSelector,void*);
+	long onCmdHeaderClicked(FXObject*,FXSelector,void*);
 public:
     static FXint ascending(const IconItem* a,const IconItem* b);
     static FXint descending(const IconItem* a,const IconItem* b);
@@ -353,7 +357,16 @@ public:
     // Move and resize this window in the parent's coordinates
     virtual void position(FXint x,FXint y,FXint w,FXint h);
 
-    // Return number of items
+    // Return ignore case flag
+	FXbool getIgnoreCase() const
+	{
+		return ignorecase;
+	}
+	
+	// Set ignore case flag
+	void setIgnoreCase(const FXbool);
+	
+	// Return number of items
     FXint getNumItems() const
     {
         return items.no();
@@ -516,8 +529,13 @@ public:
     // Return item user-data pointer
     void* getItemData(FXint index) const;
 
-    // Return TRUE if item at index is selected
-    FXbool isItemSelected(FXint index) const;
+	// Return TRUE if item is selected
+	FXbool isItemSelected(FXint index) const
+	{
+		if ((unsigned int)index >= (unsigned int)items.no())
+			fxerror("%s::isItemSelected: index out of range.\n",getClassName());
+		return items[index]->isSelected();
+	}
 
     // Return TRUE if item at index is current
     FXbool isItemCurrent(FXint index) const;
