@@ -38,7 +38,7 @@ FXIMPLEMENT(MessageBox,DialogBox,MessageBoxMap,ARRAYNUMBER(MessageBoxMap))
 
 // Construct message box with given caption, icon, and message text
 MessageBox::MessageBox(FXWindow* owner,const FXString& caption,const FXString& text,FXIcon* ic,FXuint opts,FXuint textopts,FXint x,FXint y):
-        DialogBox(owner,caption,opts|DECOR_TITLE|DECOR_BORDER,x,y,0,0, 0,0,0,0, 4,4)
+        DialogBox(owner,caption,opts|DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE,x,y,0,0, 0,0,0,0, 4,4)
 {
     initialize(text,ic,opts&BOX_BUTTON_MASK,textopts);
 }
@@ -46,7 +46,7 @@ MessageBox::MessageBox(FXWindow* owner,const FXString& caption,const FXString& t
 
 // Construct free floating message box with given caption, icon, and message text
 MessageBox::MessageBox(FXApp* a,const FXString& caption,const FXString& text,FXIcon* ic,FXuint opts,FXuint textopts,FXint x,FXint y):
-        DialogBox(a,caption,opts|DECOR_TITLE|DECOR_BORDER,x,y,0,0, 0,0,0,0, 4,4)
+        DialogBox(a,caption,opts|DECOR_TITLE|DECOR_BORDER|DECOR_STRETCHABLE,x,y,0,0, 0,0,0,0, 4,4)
 {
     initialize(text,ic,opts&BOX_BUTTON_MASK,textopts);
 }
@@ -58,7 +58,10 @@ void MessageBox::initialize(const FXString& text,FXIcon* ic, FXuint whichbuttons
     FXButton *initial;
     FXVerticalFrame* content=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXHorizontalFrame* info=new FXHorizontalFrame(content,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,10,10,10,10);
-    new FXLabel(info,text,ic,textoptions);
+
+    // Message text
+    msg=new FXLabel(info,text,ic,textoptions);
+
     new FXHorizontalSeparator(content,SEPARATOR_GROOVE|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X);
     FXHorizontalFrame* buttons=new FXHorizontalFrame(content,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,10,10,10,10);
     if(whichbuttons==BOX_OK)
