@@ -38,6 +38,9 @@ extern FXbool file_tooltips;
 // Relative resizing of the panels and columns in detailed mode
 extern FXbool relative_resize;
 
+// Save window position 
+extern FXbool save_win_pos;
+
 
 // Create hilite color from given color for gradient controls
 FXColor makeHiliteColorGradient(FXColor color)
@@ -48,9 +51,9 @@ FXColor makeHiliteColorGradient(FXColor color)
 	g=FXGREENVAL(color);
 	b=FXBLUEVAL(color);
 
-	r=FXMIN(1.2*r,255);
-	g=FXMIN(1.2*g,255);
-	b=FXMIN(1.2*b,255);
+	r=(FXuint)(FXMIN(1.2*r,255));
+	g=(FXuint)(FXMIN(1.2*g,255));
+	b=(FXuint)(FXMIN(1.2*b,255));
 
 	return FXRGB(r,g,b);
 }
@@ -65,9 +68,9 @@ FXColor makeShadowColorGradient(FXColor color)
 	g=FXGREENVAL(color);
 	b=FXBLUEVAL(color);
 
-	r=0.7*r;
-	g=0.7*g;
-	b=0.7*b;
+	r=(FXuint)(0.7*r);
+	g=(FXuint)(0.7*g);
+	b=(FXuint)(0.7*b);
 
 	return FXRGB(r,g,b);
 }
@@ -215,7 +218,8 @@ PreferencesBox::PreferencesBox(FXWindow *win, FXColor listbackcolor, FXColor lis
 
 	FXbool auto_save_layout=getApp()->reg().readUnsignedEntry("OPTIONS","auto_save_layout",TRUE);
 	autosave->setCheck(auto_save_layout);
-	FXbool save_win_pos=getApp()->reg().readUnsignedEntry("SETTINGS","save_win_pos",FALSE);
+
+    FXbool save_win_pos=getApp()->reg().readUnsignedEntry("SETTINGS","save_win_pos",FALSE);
 	savewinpos->setCheck(save_win_pos);
     
 	// Single click navigation
