@@ -37,6 +37,7 @@
 // Global variables
 extern FXMainWindow *mainWindow;
 extern FXStringDict *fsdevices;
+extern FXString xdgdatahome;
 
 
 // Map
@@ -165,11 +166,8 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	FILE *p;
 
 	// Trash locations
-	homelocation=getenv("HOME");
-    if(homelocation=="")
-        homelocation=ROOTDIR;
-	trashfileslocation=homelocation+PATHSEPSTRING+TRASHFILESPATH;
-	trashinfolocation=homelocation+PATHSEPSTRING+TRASHINFOPATH;
+	trashfileslocation=xdgdatahome + PATHSEPSTRING TRASHFILESPATH;
+	trashinfolocation=xdgdatahome + PATHSEPSTRING TRASHINFOPATH;
 
     // Buttons
     FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
@@ -304,7 +302,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 			isBrokenLink=TRUE;
 
 		// Get the path name of the linked file
-		referredpath=readlink(filepath);
+		referredpath=::readLink(filepath);
 	}
 
     orig_mode=linfo.st_mode;
@@ -332,7 +330,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		FXString dirpath=FXPath::absolute(parentdir,file);
 
 #if defined(linux)
-		FILE *mtab=setmntent("/etc/mtab","r");
+		FILE *mtab=setmntent(MTAB_PATH,"r");
         struct mntent *mnt;
         if(mtab)
         {
@@ -356,7 +354,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		if(isMountpoint)
 		{
 			// Caution : use the -P option to be POSIX compatible!
-			snprintf(buf,sizeof(buf)-1,"df -P --block-size=1 '%s'",filepath.text());
+			snprintf(buf,sizeof(buf)-1,"df -P -B 1 '%s'",filepath.text());
 			p=popen(buf,"r");
 			fgets(buf,sizeof(buf),p);
 			fgets(buf,sizeof(buf),p);
