@@ -333,7 +333,7 @@ void ViewWindow::create()
         viewer->setFont(font);
 	}
 
-    // Retain window position flag
+    // Get value of the window position flag
 	save_win_pos=reg_xfe->readUnsignedEntry("SETTINGS","save_win_pos",FALSE);
 
 	delete reg_xfe;
@@ -614,8 +614,18 @@ void ViewWindow::saveConfig()
 
 	if (save_win_pos)
 	{
-		getApp()->reg().writeIntEntry("OPTIONS","xpos",getX());
-		getApp()->reg().writeIntEntry("OPTIONS","ypos",getY());
+		// Account for the Window Manager border size
+		XWindowAttributes xwattr;
+		if (XGetWindowAttributes((Display*)getApp()->getDisplay(),this->id(),&xwattr))
+		{
+			getApp()->reg().writeIntEntry("OPTIONS","xpos",getX()-xwattr.x);
+			getApp()->reg().writeIntEntry("OPTIONS","ypos",getY()-xwattr.y);
+		}
+		else
+		{
+			getApp()->reg().writeIntEntry("OPTIONS","xpos",getX());
+			getApp()->reg().writeIntEntry("OPTIONS","ypos",getY());
+		}
 	}
 	
     // Toolbar status
