@@ -39,6 +39,9 @@ FXuint single_click;
 FXbool file_tooltips;
 FXbool relative_resize;
 FXbool save_win_pos;
+FXString homedir;
+FXString xdgconfighome;
+FXString xdgdatahome;
 
 // Hand cursor replacement
 #define hand_width 32
@@ -345,8 +348,18 @@ void XFilePackage::saveConfig()
 
 	if (save_win_pos)
 	{
-		getApp()->reg().writeIntEntry("OPTIONS","xpos",getX());
-		getApp()->reg().writeIntEntry("OPTIONS","ypos",getY());
+		// Account for the Window Manager border size
+		XWindowAttributes xwattr;
+		if (XGetWindowAttributes((Display*)getApp()->getDisplay(),this->id(),&xwattr))
+		{
+			getApp()->reg().writeIntEntry("OPTIONS","xpos",getX()-xwattr.x);
+			getApp()->reg().writeIntEntry("OPTIONS","ypos",getY()-xwattr.y);
+		}
+		else
+		{
+			getApp()->reg().writeIntEntry("OPTIONS","xpos",getX());
+			getApp()->reg().writeIntEntry("OPTIONS","ypos",getY());
+		}
 	}
 
     // Last opened filename
@@ -395,17 +408,25 @@ long XFilePackage::onUpdFileList(FXObject*,FXSelector,void*)
  
 	FXString ext=FXPath::extension(filename);
     if(comparecase(ext,"rpm")==0)
+    {
+		errorflag=FALSE;
 		cmd="rpm -qlp "+::quote(filename);
+	}
 	else if(comparecase(ext,"deb")==0)
-		cmd="dpkg -c "+::quote(filename);
-	else
 	{
-		MessageBox::error(this,BOX_OK,_("Error"),_("File list: Unknown package format"));
+		errorflag=FALSE;
+		cmd="dpkg -c "+::quote(filename);
+	}
+	else if (errorflag==FALSE)
+	{
+		errorflag=TRUE;
+    	list->clearItems();
+		MessageBox::error(this,BOX_OK,_("Error"),_("Unknown package format"));
 		return 0;
 	}
 
-    FILE *rpmcmd=popen(cmd.text(),"r");
-    if(!rpmcmd)
+    FILE *pcmd=popen(cmd.text(),"r");
+    if(!pcmd)
     {
         perror("popen");
         exit(1);
@@ -419,18 +440,20 @@ long XFilePackage::onUpdFileList(FXObject*,FXSelector,void*)
     list->clearItems();
 
     // First item
+    getApp()->beginWaitCursor();
 	FXTreeItem *topmost;
 	topmost=list->prependItem(NULL,text,minifoldericon,minifolderopenicon);
    
 	// Next items
-	while(fgets(text,sizeof(text),rpmcmd))
+	while(fgets(text,sizeof(text),pcmd))
     {
         text[strlen(text)-1]='\0';// kill trailing lf
         list->appendItem(topmost,text,minidocicon,minidocicon);
 	}
 	list->expandTree(topmost);
+    getApp()->endWaitCursor();
 	
-	pclose(rpmcmd);
+	pclose(pcmd);
 	return 1;
 }
 
@@ -448,22 +471,26 @@ long XFilePackage::onUpdDescription(FXObject*,FXSelector,void*)
 	FXString ext=FXPath::extension(filename);
     if(comparecase(ext,"rpm")==0)
 	{
+		errorflag=FALSE;
 		cmd="rpm -qip "+::quote(filename);
 		buf += _("[RPM package]\n"); 
 	}
 	else if(comparecase(ext,"deb")==0)
 	{
+		errorflag=FALSE;
 		buf += _("[DEB package]\n"); 
 		cmd="dpkg -I "+::quote(filename);
 	}
-	else
+	else if (errorflag==FALSE)
 	{
-		MessageBox::error(this,BOX_OK,_("Error"),_("Description: Unknown package format"));
+		errorflag=TRUE;
+		list->clearItems();
+		MessageBox::error(this,BOX_OK,_("Error"),_("Unknown package format"));
 		return 0;
 	}
 
-    FILE *rpmcmd=popen(cmd.text(),"r");
-    if(!rpmcmd)
+    FILE *pcmd=popen(cmd.text(),"r");
+    if(!pcmd)
     {
         perror("popen");
         exit(1);
@@ -475,14 +502,14 @@ long XFilePackage::onUpdDescription(FXObject*,FXSelector,void*)
 		suppress_header=1;
 
     char text[10000]={0};
-    while(fgets(text,sizeof(text),rpmcmd))
+    while(fgets(text,sizeof(text),pcmd))
     {
 		if (suppress_header)
 			suppress_header = (strstr(text,"Package:")==NULL); 
         if (!suppress_header) 
 			buf+=text;
     }
-    if(pclose(rpmcmd))
+    if (pclose(pcmd)==-1 && errno!=ECHILD)  // ECHILD can be set if the child was caught by sigHarvest
     {
         MessageBox::error(this,BOX_OK,_("Error"),_("Query of %s failed!"),filename.text());
 		list->clearItems();
@@ -616,6 +643,17 @@ int main(int argc,char* argv[])
 	const char *vdrname = XFEVDRNAME;
 	FXbool loadicons;
 
+	// Get environment variables $HOME, $XDG_DATA_HOME and $XDG_CONFIG_HOME
+	homedir=FXSystem::getHomeDirectory();
+    if(homedir=="")
+        homedir=ROOTDIR;
+	xdgdatahome=getenv("XDG_DATA_HOME");
+    if(xdgdatahome=="")
+        xdgdatahome=homedir + PATHSEPSTRING DATAPATH;     
+	xdgconfighome=getenv("XDG_CONFIG_HOME");
+    if(xdgconfighome=="")
+        xdgconfighome=homedir + PATHSEPSTRING CONFIGPATH;
+
 #ifdef HAVE_SETLOCALE
   // Set locale via LC_ALL.
   setlocale (LC_ALL, "");
@@ -695,7 +733,7 @@ int main(int argc,char* argv[])
 	// Set relative resizing flag according to the Xfe registry
 	relative_resize=reg_xfe->readUnsignedEntry("SETTINGS","relative_resize",TRUE);
 	
-    // Retain window position flag
+    // Get value of the window position flag
 	save_win_pos=reg_xfe->readUnsignedEntry("SETTINGS","save_win_pos",FALSE);
 
 	// Delete the Xfe registry
