@@ -4,7 +4,7 @@
 
 
 class Preferences;
-class EditWindow;
+class WriteWindow;
 
 
 // Main Application class
@@ -12,7 +12,7 @@ class XFileWrite : public FXApp
 {
     FXDECLARE(XFileWrite)
 public:
-    EditWindowList  windowlist;                   // Window list
+    WriteWindowList  windowlist;                   // Window list
 private:
     XFileWrite()
     {}
