@@ -250,11 +250,13 @@
       to the destination using the middle button of your mouse. Then modify it to suit your needs.\n \
 \n \
  Startup notification\n \
-    - If Xfe was compiled with startup notification support, the user can disable it for all applications at the global\n \
-      Preferences level. He can also disable it for individual applications, by using the dedicated option in the first\n \
-      tab of the Properties dialog. This latter way is only available when the file is an executable.\n \
-      Disabling startup notification can be useful when starting an old application that doesn't support the startup\n \
-      notification protocol (e.g. Xterm).\n \
+    - Startup notification is the process that displays a feedback (a sandbox cursor or whatever) to the user when\n \
+      he has started an action (file copying, application launching, etc.). Depending on the system, there can be\n \
+      some issues with startup notification. If Xfe was compiled with startup notification support, the user can\n \
+      disable it for all applications at the global Preferences level. He can also disable it for individual\n \
+      applications, by using the dedicated option in the first tab of the Properties dialog. This latter way is\n \
+      only available when the file is an executable. Disabling startup notification can be useful when starting\n \
+      an old application that doesn't support the startup notification protocol (e.g. Xterm).\n \
 \n \
 \n \
 \n \
@@ -285,7 +287,7 @@
  Many thanks to Maxim Baranov for his excellent X Win Commander and to all people that have provided useful\n \
  patches, translations, tests and advices.\n \
 \n \
- [Last revision: 9/11/2009]\n \
+ [Last revision: 4/03/2011]\n \
 \n \
  ")
 ;
