@@ -28,6 +28,7 @@
 // Main window
 FXMainWindow *mainWindow;
 
+
 // Startup notification
 #ifdef STARTUP_NOTIFICATION
 
@@ -195,6 +196,11 @@ FXbool deb_based=FALSE;
 FXbool rpm_based=FALSE;
 #endif
 
+// Base directories (according to the Freedesktop specification version 0.7)
+FXString homedir;
+FXString xdgdatahome;
+FXString xdgconfighome;
+
 // Used to force panel view mode from command line
 FXint panel_mode=-1;
 
@@ -260,6 +266,17 @@ int main(int argc,char *argv[])
 	FXbool iconic=FALSE;
 	FXbool maximized=FALSE;
 
+	// Get environment variables $HOME, $XDG_DATA_HOME and $XDG_CONFIG_HOME
+	homedir=FXSystem::getHomeDirectory();
+    if(homedir=="")
+        homedir=ROOTDIR;
+	xdgdatahome=getenv("XDG_DATA_HOME");
+    if(xdgdatahome=="")
+        xdgdatahome=homedir + PATHSEPSTRING DATAPATH;     
+	xdgconfighome=getenv("XDG_CONFIG_HOME");
+    if(xdgconfighome=="")
+        xdgconfighome=homedir + PATHSEPSTRING CONFIGPATH;
+
 #ifdef HAVE_SETLOCALE
   	// Set locale via LC_ALL.
   	setlocale (LC_ALL, "");
@@ -382,7 +399,7 @@ int main(int argc,char *argv[])
     	FXFont* normalFont=new FXFont(application,fontspec);
         application->setNormalFont(normalFont);
     }
- 
+	
     // If root
 	if (getuid()==0)
         title="Xfe (root)";
