@@ -1,7 +1,7 @@
 // Common Xfe constants
 
 #ifndef COPYRIGHT
-#define COPYRIGHT "Copyright (C) 2002-2009 Roland Baudin (roland65@free.fr)"
+#define COPYRIGHT "Copyright (C) 2002-2011 Roland Baudin (roland65@free.fr)"
 #endif
 
 // Default initial main window width
@@ -74,17 +74,17 @@
 
 // Run history size
 #ifndef RUN_HIST_SIZE
-#define RUN_HIST_SIZE 20
+#define RUN_HIST_SIZE 30
 #endif
 
 // Open with history size
 #ifndef OPEN_HIST_SIZE
-#define OPEN_HIST_SIZE 20
+#define OPEN_HIST_SIZE 30
 #endif
 
 // Filter history size
 #ifndef FILTER_HIST_SIZE
-#define FILTER_HIST_SIZE 20
+#define FILTER_HIST_SIZE 30
 #endif
 
 #ifdef STARTUP_NOTIFICATION
@@ -95,24 +95,34 @@
 // If startup notification is not used, we use an ugly simulation of a startup time (seconds)
 #define SIMULATED_STARTUP_TIME 3
 
-// Local Xfe directory path
-#ifndef LOCALPATH
-#define LOCALPATH ".config/xfe"
+// Local data path
+#ifndef DATAPATH
+#define DATAPATH ".local/share"
+#endif
+
+// Local config path
+#ifndef CONFIGPATH
+#define CONFIGPATH ".config"
+#endif
+
+// Xfe config path
+#ifndef XFECONFIGPATH
+#define XFECONFIGPATH "xfe"
 #endif
 
 // Local trashcan directory path
 #ifndef TRASHPATH
-#define TRASHPATH ".local/share/Trash"
+#define TRASHPATH "Trash"
 #endif
 
 // Local trashcan directory path for files
 #ifndef TRASHFILESPATH
-#define TRASHFILESPATH ".local/share/Trash/files"
+#define TRASHFILESPATH "Trash/files"
 #endif
 
 // Local trashcan directory path for infos
 #ifndef TRASHINFOPATH
-#define TRASHINFOPATH ".local/share/Trash/info"
+#define TRASHINFOPATH "Trash/info"
 #endif
 
 // Xfe application name
@@ -220,3 +230,19 @@
 // Macro to add parentheses before and after a given string
 #define PARS(s) ((FXString)" ("+(s)+(FXString)")")
 
+
+// Linux specials
+
+#if defined(linux)
+
+// fstab path
+#ifndef FSTAB_PATH
+#define FSTAB_PATH "/etc/fstab"
+#endif
+
+// mtab path
+#ifndef MTAB_PATH
+#define MTAB_PATH "/proc/mounts"
+#endif
+
+#endif
